pub const unsafe fn encode_reg64(reg64: GPR) -> EncodedX86_64InstructionExpand description
Push 64-bit register onto the stack.
Safety
It is the caller’s responsibility to ensure that the operands are valid. Otherwise the behavior is undefined.
pub const unsafe fn encode_reg64(reg64: GPR) -> EncodedX86_64InstructionPush 64-bit register onto the stack.
It is the caller’s responsibility to ensure that the operands are valid. Otherwise the behavior is undefined.